@@ -36,8 +36,10 @@ def version():
         - get_MySubQuery增加注释
         - order_qs_ls_by_id完善为不限制长度
         - zip功能完善       # 2.4.2
+        - get_base_serializer解决'__all__'和retrieve时出现的bug        # 2.4.3
+        - retrieve_filter_field现在可由前端指定
     """
-    v = "2.4.2"
+    v = "2.4.3"
     return v
 
 
