@@ -93,6 +93,12 @@ def set_query_dc_value(query_dc: QueryDict, new_dc: dict):
     return query_dc
 
 
+def get_field_names_by_model(model_class):
+    fields = model_class._meta.fields
+    field_names = [getattr(field, 'name') for field in fields]
+    return field_names
+
+
 def get_base_serializer(base_model, base_fields='__all__', auto_generate_annotate_fields=None):
     """
     生成一个基础序列化器
@@ -103,8 +109,12 @@ def get_base_serializer(base_model, base_fields='__all__', auto_generate_annotat
     :return:
     """
     base_model = get_base_model(base_model)
+    field_names = get_field_names_by_model(base_model)
+    if base_fields != '__all__' and auto_generate_annotate_fields is None:
+        if len(set(base_fields) - set(field_names)):
+            auto_generate_annotate_fields = True
 
-    if not pure.convert_query_parameter_to_bool(auto_generate_annotate_fields):
+    if auto_generate_annotate_fields is None:
         class BaseSerializer(s.ModelSerializer):
             class Meta:
                 model = base_model
@@ -115,16 +125,16 @@ def get_base_serializer(base_model, base_fields='__all__', auto_generate_annotat
     else:
         if auto_generate_annotate_fields is True or auto_generate_annotate_fields in ['__all__', ['__all__']]:
             auto_generate_annotate_fields = base_fields
-        elif isinstance(auto_generate_annotate_fields, str):
-            auto_generate_annotate_fields = [auto_generate_annotate_fields]
-
-        field_names = [dc.name for dc in base_model._meta.fields]
+        elif isinstance(auto_generate_annotate_fields, list):
+            auto_generate_annotate_fields = auto_generate_annotate_fields + field_names
+        else:
+            raise ValueError(f"auto_generate_annotate_fields[{auto_generate_annotate_fields}]取值错误!")
 
         # --- 这里要把queryset里有, 但model.fields里没有的字段在serializers时自动加上
         new_dc_ls = []
         new_func_ls = []
-        for field in base_fields:
-            if field not in field_names and field in auto_generate_annotate_fields:
+        for field in auto_generate_annotate_fields:
+            if field not in field_names and field not in '__all__':
                 # 指定方法字段 SerializerMethodField 后, 再增加 get_field_function.
                 field_method = s.SerializerMethodField()
                 new_func_name = f'get_{field}'
@@ -712,3 +722,53 @@ def judge_db_is_migrating():
         return False
 
 
+def get_total_occurance_times_by_keywords(total_qs_ls, search_field_ls, keywords, get_frequence=False):
+    """
+    统计keywords在qs_ls的search_field_ls中是否出现
+
+    :param total_qs_ls: 用来统计的queryset
+    :param search_field_ls: 要匹配的字段
+    :param kw: 用来检索的关键词
+    :param get_frequence: 是否精确计算kw在字段中出现的次数
+    :return: queryset, 且annotate出现次数, 存在`total_occurance_times`字段中
+    """
+    from django.db.models import functions
+
+    my_api_assert_function(isinstance(keywords, list), 'keywords的类型必须为list!')
+    search_dc = {}
+    occurance_times_ls = []
+
+    for k in range(len(keywords)):
+        kw = keywords[k]
+        kw_l = len(kw)
+        for sf_i in search_field_ls:
+            if get_frequence:
+                k_name = f'k{k}_{sf_i}_occurance_times'
+                dc = {
+                    k_name: (functions.Length(sf_i) - functions.Length(
+                        functions.Replace(sf_i, m.Value(kw), m.Value('')))) / kw_l  # 出现次数
+                }
+            else:
+                k_name = f'k{k}_in_{sf_i}'
+                dc = {
+                    k_name: m.Exists(total_qs_ls.filter(id=m.OuterRef('id')).filter(**{f'{sf_i}__contains': kw})),   # 判断是否在title中
+                }
+            occurance_times_ls.append(k_name)
+            search_dc.update(dc)
+    res_qs_ls: m.QuerySet = total_qs_ls.annotate(**search_dc)
+    # show_ls(res_qs_ls.values(*(['id'] + search_field_ls + list(search_dc.keys())))[:3])
+
+    f_ls = 0
+    for i in occurance_times_ls:
+        if get_frequence:
+            f_ls += F(i)
+        else:
+            f_ls += m.Case(
+                m.When(**{i: True}, then=m.Value(1)),
+                default=0,
+                output_field=m.IntegerField()
+            )
+
+    res_qs_ls = res_qs_ls.annotate(**{'total_occurance_times': f_ls})
+    ret = res_qs_ls
+    return ret
