@@ -31,7 +31,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     retrieve_serializer_class = None  # retrieve对应的serializer_class
     list_serializer_class = None  # list对应的serializer_class
 
-    retrieve_filter_field = None  # 详情页的查询字段名, 默认为 {{url}}/app/view/pk , 无需变动.
+    retrieve_filter_field = 'pk'  # 详情页的查询字段名, 默认为 {{url}}/app/view/pk , 可由前端指定.
 
     method = None  # 中间变量, 记录请求是什么类型, list/retrieve等
     _tmp = None  # 无意义, 用来处理数据
@@ -43,7 +43,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     convert_to_bool_flag = 'bool__'                       # 将特定格式强制转换为布尔变量, 如 `名字不为空: name__isnull=bool_0`
     negative_flag = '!'                                   # filter_fields 条件取否时使用, 如: `id不等于1: !id=1`
 
-    def get(self, request: Request, *args, **kwargs):
+    def get(self, request, *args, **kwargs):
         """
         - 如果request携带pk参数, 则进行Retrieve操作, 否则进行List操作.
 
@@ -146,7 +146,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         ret = self.get_key_from_query_dc_or_self(key, get_type='list')
         return ret
 
-    def get_retrieve_ret(self, request: Request, *args, **kwargs):
+    def get_retrieve_ret(self, request, *args, **kwargs):
         """
         Retrieve操作
 
@@ -172,7 +172,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
 
     def get_object(self):
         """retrieve时, object的获取"""
-        retrieve_filter_field = self.retrieve_filter_field if self.retrieve_filter_field else 'id'
+        retrieve_filter_field = self.get_key_from_query_dc_or_self('retrieve_filter_field')
 
         pk = self.request.parser_context.get('kwargs').get('pk')
         dc = {retrieve_filter_field: pk}
@@ -182,19 +182,19 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
             queryset = queryset.filter(Q(**dc))
         else:
             queryset = queryset.objects.filter(Q(**dc))
-        print(get_executable_sql(queryset))
+        # print(get_executable_sql(queryset))
 
         if queryset.count() != 1:
             if queryset.count() > 1:
                 my_api_assert_function(False, f'检索结果不唯一!')
             else:
-                my_api_assert_function(False, f'未检索到id对应的内容!')
+                my_api_assert_function(False, f'未检索到{dc}对应的内容!')
 
         obj = queryset[0]
         self.check_object_permissions(self.request, obj)
         return obj
 
-    def get_list_ret(self, request: Request, *args, **kwargs):
+    def get_list_ret(self, request, *args, **kwargs):
         """
         List操作
         """
@@ -363,7 +363,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     def _get_list_queryset(self):  # 兼容问题
         return self.get_list_queryset()
 
-    def list(self, request: Request, *args, **kwargs):
+    def list(self, request, *args, **kwargs):
         query_dc = self.get_request_data()
         page_size = query_dc.get('page_size', self.pagination_class.page_size)
         p = query_dc.get('p', 1)
